==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/awscdk/LambdaFunctionCommonOptions.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Common options for `LambdaFunction`.
 * <p>
 * Applies to all functions in
 * auto-discovery.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.613Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.LambdaFunctionCommonOptions")
@software.amazon.jsii.Jsii.Proxy(LambdaFunctionCommonOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface LambdaFunctionCommonOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Bundling options for this AWS Lambda function.
     * <p>
     * If not specified the default bundling options specified for the project
     * <code>Bundler</code> instance will be used.
     * <p>
     * Default: - defaults
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.BundlingOptions getBundlingOptions() {
        return null;
    }

    /**
     * (experimental) The node.js version to target.
     * <p>
     * Default: Runtime.NODEJS_14_X
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.awscdk.LambdaRuntime getRuntime() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LambdaFunctionCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaFunctionCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<LambdaFunctionCommonOptions> {
        io.github.cdklabs.projen.javascript.BundlingOptions bundlingOptions;
        io.github.cdklabs.projen.awscdk.LambdaRuntime runtime;

        /**
         * Sets the value of {@link LambdaFunctionCommonOptions#getBundlingOptions}
         * @param bundlingOptions Bundling options for this AWS Lambda function.
         *                        If not specified the default bundling options specified for the project
         *                        <code>Bundler</code> instance will be used.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder bundlingOptions(io.github.cdklabs.projen.javascript.BundlingOptions bundlingOptions) {
            this.bundlingOptions = bundlingOptions;
            return this;
        }

        /**
         * Sets the value of {@link LambdaFunctionCommonOptions#getRuntime}
         * @param runtime The node.js version to target.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runtime(io.github.cdklabs.projen.awscdk.LambdaRuntime runtime) {
            this.runtime = runtime;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaFunctionCommonOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public LambdaFunctionCommonOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LambdaFunctionCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaFunctionCommonOptions {
        private final io.github.cdklabs.projen.javascript.BundlingOptions bundlingOptions;
        private final io.github.cdklabs.projen.awscdk.LambdaRuntime runtime;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.bundlingOptions = software.amazon.jsii.Kernel.get(this, "bundlingOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.BundlingOptions.class));
            this.runtime = software.amazon.jsii.Kernel.get(this, "runtime", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.awscdk.LambdaRuntime.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.bundlingOptions = builder.bundlingOptions;
            this.runtime = builder.runtime;
        }

        @Override
        public final io.github.cdklabs.projen.javascript.BundlingOptions getBundlingOptions() {
            return this.bundlingOptions;
        }

        @Override
        public final io.github.cdklabs.projen.awscdk.LambdaRuntime getRuntime() {
            return this.runtime;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBundlingOptions() != null) {
                data.set("bundlingOptions", om.valueToTree(this.getBundlingOptions()));
            }
            if (this.getRuntime() != null) {
                data.set("runtime", om.valueToTree(this.getRuntime()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.awscdk.LambdaFunctionCommonOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaFunctionCommonOptions.Jsii$Proxy that = (LambdaFunctionCommonOptions.Jsii$Proxy) o;

            if (this.bundlingOptions != null ? !this.bundlingOptions.equals(that.bundlingOptions) : that.bundlingOptions != null) return false;
            return this.runtime != null ? this.runtime.equals(that.runtime) : that.runtime == null;
        }

        @Override
        public final int hashCode() {
            int result = this.bundlingOptions != null ? this.bundlingOptions.hashCode() : 0;
            result = 31 * result + (this.runtime != null ? this.runtime.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/awscdk/LambdaFunctionCommonOptions.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Common options for <code>LambdaFunction</code>.
 * <p>
 * Applies to all functions in
 * auto-discovery.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.288Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.LambdaFunctionCommonOptions")
@software.amazon.jsii.Jsii.Proxy(LambdaFunctionCommonOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface LambdaFunctionCommonOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Whether to automatically reuse TCP connections when working with the AWS SDK for JavaScript.
     * <p>
     * This sets the <code>AWS_NODEJS_CONNECTION_REUSE_ENABLED</code> environment variable
     * to <code>1</code>.
     * <p>
     * Not applicable when <code>edgeLambda</code> is set to <code>true</code> because environment
     * variables are not supported in Lambda&#64;Edge.
     * <p>
     * Default: true
     * <p>
     * @see <a href="https://docs.aws.amazon.com/sdk-for-javascript/v2/developer-guide/node-reusing-connections.html">https://docs.aws.amazon.com/sdk-for-javascript/v2/developer-guide/node-reusing-connections.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAwsSdkConnectionReuse() {
        return null;
    }

    /**
     * (experimental) Bundling options for this AWS Lambda function.
     * <p>
     * If not specified the default bundling options specified for the project
     * <code>Bundler</code> instance will be used.
     * <p>
     * Default: - defaults
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.BundlingOptions getBundlingOptions() {
        return null;
    }

    /**
     * (experimental) Whether to create a <code>cloudfront.experimental.EdgeFunction</code> instead of a <code>lambda.Function</code>.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getEdgeLambda() {
        return null;
    }

    /**
     * (experimental) The node.js version to target.
     * <p>
     * Default: Runtime.NODEJS_18_X
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.awscdk.LambdaRuntime getRuntime() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LambdaFunctionCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaFunctionCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<LambdaFunctionCommonOptions> {
        java.lang.Boolean awsSdkConnectionReuse;
        io.github.cdklabs.projen.javascript.BundlingOptions bundlingOptions;
        java.lang.Boolean edgeLambda;
        io.github.cdklabs.projen.awscdk.LambdaRuntime runtime;

        /**
         * Sets the value of {@link LambdaFunctionCommonOptions#getAwsSdkConnectionReuse}
         * @param awsSdkConnectionReuse Whether to automatically reuse TCP connections when working with the AWS SDK for JavaScript.
         *                              This sets the <code>AWS_NODEJS_CONNECTION_REUSE_ENABLED</code> environment variable
         *                              to <code>1</code>.
         *                              <p>
         *                              Not applicable when <code>edgeLambda</code> is set to <code>true</code> because environment
         *                              variables are not supported in Lambda&#64;Edge.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder awsSdkConnectionReuse(java.lang.Boolean awsSdkConnectionReuse) {
            this.awsSdkConnectionReuse = awsSdkConnectionReuse;
            return this;
        }

        /**
         * Sets the value of {@link LambdaFunctionCommonOptions#getBundlingOptions}
         * @param bundlingOptions Bundling options for this AWS Lambda function.
         *                        If not specified the default bundling options specified for the project
         *                        <code>Bundler</code> instance will be used.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder bundlingOptions(io.github.cdklabs.projen.javascript.BundlingOptions bundlingOptions) {
            this.bundlingOptions = bundlingOptions;
            return this;
        }

        /**
         * Sets the value of {@link LambdaFunctionCommonOptions#getEdgeLambda}
         * @param edgeLambda Whether to create a <code>cloudfront.experimental.EdgeFunction</code> instead of a <code>lambda.Function</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder edgeLambda(java.lang.Boolean edgeLambda) {
            this.edgeLambda = edgeLambda;
            return this;
        }

        /**
         * Sets the value of {@link LambdaFunctionCommonOptions#getRuntime}
         * @param runtime The node.js version to target.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runtime(io.github.cdklabs.projen.awscdk.LambdaRuntime runtime) {
            this.runtime = runtime;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaFunctionCommonOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public LambdaFunctionCommonOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LambdaFunctionCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaFunctionCommonOptions {
        private final java.lang.Boolean awsSdkConnectionReuse;
        private final io.github.cdklabs.projen.javascript.BundlingOptions bundlingOptions;
        private final java.lang.Boolean edgeLambda;
        private final io.github.cdklabs.projen.awscdk.LambdaRuntime runtime;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.awsSdkConnectionReuse = software.amazon.jsii.Kernel.get(this, "awsSdkConnectionReuse", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.bundlingOptions = software.amazon.jsii.Kernel.get(this, "bundlingOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.BundlingOptions.class));
            this.edgeLambda = software.amazon.jsii.Kernel.get(this, "edgeLambda", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.runtime = software.amazon.jsii.Kernel.get(this, "runtime", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.awscdk.LambdaRuntime.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.awsSdkConnectionReuse = builder.awsSdkConnectionReuse;
            this.bundlingOptions = builder.bundlingOptions;
            this.edgeLambda = builder.edgeLambda;
            this.runtime = builder.runtime;
        }

        @Override
        public final java.lang.Boolean getAwsSdkConnectionReuse() {
            return this.awsSdkConnectionReuse;
        }

        @Override
        public final io.github.cdklabs.projen.javascript.BundlingOptions getBundlingOptions() {
            return this.bundlingOptions;
        }

        @Override
        public final java.lang.Boolean getEdgeLambda() {
            return this.edgeLambda;
        }

        @Override
        public final io.github.cdklabs.projen.awscdk.LambdaRuntime getRuntime() {
            return this.runtime;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAwsSdkConnectionReuse() != null) {
                data.set("awsSdkConnectionReuse", om.valueToTree(this.getAwsSdkConnectionReuse()));
            }
            if (this.getBundlingOptions() != null) {
                data.set("bundlingOptions", om.valueToTree(this.getBundlingOptions()));
            }
            if (this.getEdgeLambda() != null) {
                data.set("edgeLambda", om.valueToTree(this.getEdgeLambda()));
            }
            if (this.getRuntime() != null) {
                data.set("runtime", om.valueToTree(this.getRuntime()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.awscdk.LambdaFunctionCommonOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaFunctionCommonOptions.Jsii$Proxy that = (LambdaFunctionCommonOptions.Jsii$Proxy) o;

            if (this.awsSdkConnectionReuse != null ? !this.awsSdkConnectionReuse.equals(that.awsSdkConnectionReuse) : that.awsSdkConnectionReuse != null) return false;
            if (this.bundlingOptions != null ? !this.bundlingOptions.equals(that.bundlingOptions) : that.bundlingOptions != null) return false;
            if (this.edgeLambda != null ? !this.edgeLambda.equals(that.edgeLambda) : that.edgeLambda != null) return false;
            return this.runtime != null ? this.runtime.equals(that.runtime) : that.runtime == null;
        }

        @Override
        public final int hashCode() {
            int result = this.awsSdkConnectionReuse != null ? this.awsSdkConnectionReuse.hashCode() : 0;
            result = 31 * result + (this.bundlingOptions != null ? this.bundlingOptions.hashCode() : 0);
            result = 31 * result + (this.edgeLambda != null ? this.edgeLambda.hashCode() : 0);
            result = 31 * result + (this.runtime != null ? this.runtime.hashCode() : 0);
            return result;
        }
    }
}
